package svc

import (
	"applet/app/e"
	"applet/app/md"
	"applet/app/utils"
	db "code.fnuoos.com/zhimeng/model.git/src"
	"fmt"
	"github.com/gin-gonic/gin"
	"time"
)

func IndexTotal(c *gin.Context) {
	yesterday := utils.GetTimeRange("yesterday")
	yesterdayTotal := commTotal(c, time.Unix(yesterday["start"], 0).Format("2006-01-02"), time.Unix(yesterday["end"]-3600, 0).Format("2006-01-02"))
	withinSevenDays := utils.GetTimeRange("new_within_seven_days")
	withinSevenDaysTotal := commTotal(c, time.Unix(withinSevenDays["start"], 0).Format("2006-01-02"), time.Unix(withinSevenDays["end"]-3600, 0).Format("2006-01-02"))
	currentMonth := utils.GetTimeRange("current_month")
	currentMonthTotal := commTotal(c, time.Unix(currentMonth["start"], 0).Format("2006-01-02"), time.Unix(currentMonth["end"]-3600, 0).Format("2006-01-02"))
	lastMonth := utils.GetTimeRange("last_month")
	lastMonthTotal := commTotal(c, time.Unix(lastMonth["start"], 0).Format("2006-01-02"), time.Unix(lastMonth["end"]-3600, 0).Format("2006-01-02"))
	res := []md.IndexAppListDataList{
		{Name: "昨日收益", Type: "yesterday", Bili: "-%", Value: utils.Float64ToStr(utils.StrToFloat64(yesterdayTotal[0]["media_revenue"]) / 100)},
		{Name: "七日收益", Type: "within_seven_days", Bili: "-%", Value: utils.Float64ToStr(utils.StrToFloat64(withinSevenDaysTotal[0]["media_revenue"]) / 100)},
		{Name: "本月收益", Type: "current_month", Bili: "-%", Value: utils.Float64ToStr(utils.StrToFloat64(currentMonthTotal[0]["media_revenue"]) / 100)},
		{Name: "上月收益", Type: "last_month", Bili: "-%", Value: utils.Float64ToStr(utils.StrToFloat64(lastMonthTotal[0]["media_revenue"]) / 100)},
	}
	e.OutSuc(c, res, nil)
	return
}
func IndexAppList(c *gin.Context, req md.IndexAppListReq) md.IndexAppListRes {
	data := commTotalByApp(c, req)
	list := make([]md.IndexAppListData, 0)
	for _, v := range data {
		dataList := []md.IndexAppListDataList{
			{Name: "广告预估收益", Type: "media_revenue", Bili: "-%", Value: utils.Float64ToStr(utils.StrToFloat64(v["media_revenue"]) / 100)},
			{Name: "ECPM", Type: "ecpm", Bili: "-%", Value: v["ecpm"]},
			{Name: "曝光量", Type: "exposure_count", Bili: "-%", Value: v["exposure_count"]},
			{Name: "点击量", Type: "click_count", Bili: "-%", Value: v["click_count"]},
			{Name: "点击率", Type: "click_rate", Bili: "-%", Value: utils.GetPrec(v["click_rate"], "2")},
		}
		applet := GetAppletInfo(c, v["app_id"])
		tmp := md.IndexAppListData{
			Name:      applet["name"],
			Logo:      applet["logo"],
			List:      dataList,
			TableList: []string{},
		}
		list = append(list, tmp)
	}
	res := md.IndexAppListRes{
		List: list,
		Sort: []md.SelectData{
			{Name: "按收益最高", Value: "media_revenue desc"},
			{Name: "按ECPM最高", Value: "ecpm desc"},
			{Name: "按曝光量最高", Value: "exposure_count desc"},
		},
	}
	return res
}
func commTotal(c *gin.Context, startDate, endDate string) []map[string]string {
	sql := `
		SELECT 
			SUM(exposure_count) as exposure_count,
			SUM(click_count) as click_count,
			SUM(click_rate) as click_rate,
			SUM(ecpm) as ecpm,
			SUM(media_revenue) as media_revenue
		FROM generate_wx_ad_data
		where %s 
`
	where := "uuid=" + c.GetString("mid")
	if startDate != "" {
		where += " and date>='" + startDate + "'"
	}
	if endDate != "" {
		where += " and date<='" + endDate + "'"
	}
	sql = fmt.Sprintf(sql, where)
	nativeString, _ := db.QueryNativeString(db.Db, sql)
	if len(nativeString) == 0 {
		nativeString = []map[string]string{
			{
				"media_revenue": "0",
			},
		}
	}
	return nativeString
}
func commTotalByApp(c *gin.Context, req md.IndexAppListReq) []map[string]string {
	sql := `
		SELECT 
			app_id as app_id,
			SUM(exposure_count) as exposure_count,
			SUM(click_count) as click_count,
			SUM(click_count)/SUM(exposure_count)*100 as click_rate,
			SUM(ecpm) as ecpm,
			SUM(media_revenue) as media_revenue
		FROM generate_wx_ad_data
		where %s group by app_id order by %s,id asc limit 10
`
	where := "uuid=" + c.GetString("mid")
	if req.StartDate != "" {
		where += " and date>='" + req.StartDate + "'"
	}
	if req.EndDate != "" {
		where += " and date<='" + req.EndDate + "'"
	}
	if req.Sort == "" {
		req.Sort = "media_revenue desc"
	}
	sql = fmt.Sprintf(sql, where, req.Sort)
	nativeString, _ := db.QueryNativeString(db.Db, sql)
	if len(nativeString) == 0 {
		nativeString = []map[string]string{
			{
				"media_revenue": "0",
			},
		}
	}
	return nativeString
}
